# -*- encoding: utf-8 -*-
# (C) Copyright 2008 Tarek Ziadé <tarek@ziade.org>
""" 
Mail output plugin.
"""
from email.MIMEText import MIMEText

class Mail(object):
    """Will send an alert by mail"""

    def __call__(self, entries, enhancers, args):
        
        # a mail is built, using MimeText
        msg = MIMEText() 




from setuptools import setup, find_packages
import os

version = '0.1.0'

long_description = open("README.txt").read()
classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ]

entry_points = {"atomisator.outputs": 
        ["email = atomisator.outputs.mail:Mail"]}

setup(name='atomisator.outputs',
      version=version,
      description="Expert Python Programming - Outputs",
      long_description=long_description,
      classifiers=classifiers,
      keywords='python best practices',
      author='Tarek Ziade',
      author_email='tarek@ziade.org',
      url='http://atomisator.ziade.org',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['atomisator'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points=entry_points,
      )

